.. _dining-philosophers:

========================
Dining Philosophers
========================

The code for this example is located in the :mod:`examples.philosophers.manage`
module.

.. automodule:: examples.philosophers.manage
